@@ -7,9 +7,9 @@ use strict;
 
 use Crypt::SmbHash;
 #======================================================================
-$VERSION = '0.12';
+$VERSION = '0.13';
 @ISA = qw(Exporter);
-@EXPORT_OK = qw(del uid maxuid passwd rename users);
+@EXPORT_OK = qw(del uid maxuid passwd rename user users);
 #======================================================================
 use constant PASSWD => '/etc/samba/smbpasswd';
 #======================================================================
@@ -96,6 +96,8 @@ sub maxuid {
 	return $max;
 }
 #======================================================================
+*user = \&passwd;
+#======================================================================
 sub passwd {
 	shift if $_[0] =~ __PACKAGE__;
 	
@@ -186,6 +188,10 @@ This method changes the username for a user. If NEWNAME corresponds to an existi
 
 Read or modify a user's UID. Returns the result of operation (TRUE or FALSE) if UID was specified otherwhise returns the UID.
 
+=item B<user()>
+
+This alias for passwd. User is created if doesn't exists. 
+
 =item B<users()>
 
 This method returns a list of all existing usernames. 
